@@ -16,7 +16,7 @@ except ImportError as e:
     raise ImportError('Please add ObserverTools/bin to your PYTHONPATH:\n'
                       '    {}'.format(e))
 
-__version__ = '3.1.1'
+__version__ = '3.2.0'
 
 
 class LogSupport:
@@ -44,12 +44,17 @@ class LogSupport:
         return data
 
     def set_callbacks(self):
-        data = self.telemetry.get(['25m:sop:doMangaSequence_ditherSeq:index',
-                                   '25m:sop:doApogeeMangaSequence_ditherSeq'
-                                   ':index',
+        data = self.telemetry.get([  # '25m:sop:doApogeeBossScience_nDither'
+                                   # ':nDitherDone',
+                                   '25m:sop:doBossScience_nExp'
+                                   ':nExpDone',
+                                   '25m:sop:doMangaSequence_ditherSeq:index',
+                                   '25m:sop:doApogeeMangaSequence_ditherSeq:'
+                                   'index',
                                    '25m:sop:doApogeeScience_index:index'],
                                   (self.tstart - 0.3).datetime,
-                                  (self.tend - 0.3).datetime, interpolation='raw',
+                                  (self.tend - 0.3).datetime,
+                                  interpolation='raw',
                                   scan_archives=False)
         self.call_times = []
         for dat in data:
@@ -207,7 +212,8 @@ class LogSupport:
 
         data = self.telemetry.get('25m:hartmann:sp1Residuals:deg',
                                   (self.tstart - 0.3).datetime,
-                                  (self.tend - 0.3).datetime, interpolation='raw',
+                                  (self.tend - 0.3).datetime,
+                                  interpolation='raw',
                                   scan_archives=False)
         hart_times = data.times
         hart_times = Time(hart_times)
